verticalitytools.label_vertical_moments_in_expr_with_chromatic_interval_classes
===============================================================================

.. autofunction:: abjad.tools.verticalitytools.label_vertical_moments_in_expr_with_chromatic_interval_classes.label_vertical_moments_in_expr_with_chromatic_interval_classes
